==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification.md <==
# AmazonSimpleNotificationServiceEmailNotification


```text
aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification
```

```text
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification')
```



| Illustration | AmazonSimpleNotificationServiceEmailNotification | AmazonSimpleNotificationServiceEmailNotificationCard | AmazonSimpleNotificationServiceEmailNotificationGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification.png) | ![illustration for AmazonSimpleNotificationServiceEmailNotification](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification.Local.png) | ![illustration for AmazonSimpleNotificationServiceEmailNotificationCard](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotificationCard.Local.png) | ![illustration for AmazonSimpleNotificationServiceEmailNotificationGroup](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotificationGroup.Local.png) |




## AmazonSimpleNotificationServiceEmailNotification

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceEmailNotification
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification')

' renders the element
AmazonSimpleNotificationServiceEmailNotification('AmazonSimpleNotificationServiceEmailNotification', 'Amazon Simple Notification Service Email Notification', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceEmailNotification
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification')

' renders the element
AmazonSimpleNotificationServiceEmailNotification('AmazonSimpleNotificationServiceEmailNotification', 'Amazon Simple Notification Service Email Notification', 'an optional tech label')
@enduml
```

## AmazonSimpleNotificationServiceEmailNotificationCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceEmailNotificationCard
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification')

' renders the element
AmazonSimpleNotificationServiceEmailNotificationCard('AmazonSimpleNotificationServiceEmailNotificationCard', 'Amazon Simple Notification Service Email Notification Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceEmailNotificationCard
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification')

' renders the element
AmazonSimpleNotificationServiceEmailNotificationCard('AmazonSimpleNotificationServiceEmailNotificationCard', 'Amazon Simple Notification Service Email Notification Card', 'an optional description')
@enduml
```

## AmazonSimpleNotificationServiceEmailNotificationGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceEmailNotificationGroup
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification')

' renders the element
AmazonSimpleNotificationServiceEmailNotificationGroup('AmazonSimpleNotificationServiceEmailNotificationGroup', 'Amazon Simple Notification Service Email Notification Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceEmailNotificationGroup
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification')

' renders the element
AmazonSimpleNotificationServiceEmailNotificationGroup('AmazonSimpleNotificationServiceEmailNotificationGroup', 'Amazon Simple Notification Service Email Notification Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification.md <==
# AmazonSimpleNotificationServiceEmailNotification


```text
aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification
```

```text
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification')
```



| Illustration | AmazonSimpleNotificationServiceEmailNotification | AmazonSimpleNotificationServiceEmailNotificationCard | AmazonSimpleNotificationServiceEmailNotificationGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification.png) | ![illustration for AmazonSimpleNotificationServiceEmailNotification](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification.Local.png) | ![illustration for AmazonSimpleNotificationServiceEmailNotificationCard](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotificationCard.Local.png) | ![illustration for AmazonSimpleNotificationServiceEmailNotificationGroup](../../../aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotificationGroup.Local.png) |




## AmazonSimpleNotificationServiceEmailNotification

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceEmailNotification
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification')

' renders the element
AmazonSimpleNotificationServiceEmailNotification('AmazonSimpleNotificationServiceEmailNotification', 'Amazon Simple Notification Service Email Notification', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceEmailNotification
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification')

' renders the element
AmazonSimpleNotificationServiceEmailNotification('AmazonSimpleNotificationServiceEmailNotification', 'Amazon Simple Notification Service Email Notification', 'an optional tech label')
@enduml
```

## AmazonSimpleNotificationServiceEmailNotificationCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceEmailNotificationCard
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification')

' renders the element
AmazonSimpleNotificationServiceEmailNotificationCard('AmazonSimpleNotificationServiceEmailNotificationCard', 'Amazon Simple Notification Service Email Notification Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceEmailNotificationCard
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification')

' renders the element
AmazonSimpleNotificationServiceEmailNotificationCard('AmazonSimpleNotificationServiceEmailNotificationCard', 'Amazon Simple Notification Service Email Notification Card', 'an optional description')
@enduml
```

## AmazonSimpleNotificationServiceEmailNotificationGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceEmailNotificationGroup
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification')

' renders the element
AmazonSimpleNotificationServiceEmailNotificationGroup('AmazonSimpleNotificationServiceEmailNotificationGroup', 'Amazon Simple Notification Service Email Notification Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonSimpleNotificationServiceEmailNotificationGroup
include('aws-q3-2021/Resource/ApplicationIntegration/AmazonSimpleNotificationServiceEmailNotification')

' renders the element
AmazonSimpleNotificationServiceEmailNotificationGroup('AmazonSimpleNotificationServiceEmailNotificationGroup', 'Amazon Simple Notification Service Email Notification Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
